from distutils.core import setup
setup(
  name = 'dig_indicator_incall',
  packages = ['dig_indicator_incall'], # this must be the same as the name above
  version = '1.2',
  description = 'Domain: indicator',
  author = 'Jiayuan Ding',
  author_email = 'jiayuand@usc.edu',
  url = 'https://github.com/usc-isi-i2/dig-indicators-data/tree/master/Code/dig_indicator_incall', #github 
  download_url = 'https://github.com/usc-isi-i2/dig_indicator_incall/tree/master/Code/dig_indicator_incall/archive/1.2.tar.gz', # I'll explain this in a second
  keywords = ['incall', 'domain', 'dig'], # arbitrary keywords
  classifiers = [],
)
